@@ -15,6 +15,23 @@
 /* Parent GTK object class */
 static BonoboObjectClass *bonobo_persist_parent_class;
 
+#define CLASS(o) BONOBO_PERSIST_CLASS(GTK_OBJECT(o)->klass)
+
+static inline BonoboPersist *
+bonobo_persist_from_servant (PortableServer_Servant servant)
+{
+	return BONOBO_PERSIST (bonobo_object_from_servant (servant));
+}
+
+static Bonobo_Persist_ContentTypeList *
+impl_get_content_types (PortableServer_Servant	servant,
+			CORBA_Environment	*ev)
+{
+	BonoboPersist *persist = bonobo_persist_from_servant (servant);
+
+	return CLASS (persist)->get_content_types (persist, ev);
+}
+
 /**
  * bonobo_persist_get_epv:
  */
@@ -25,6 +42,8 @@ bonobo_persist_get_epv (void)
 
 	epv = g_new0 (POA_Bonobo_Persist__epv, 1);
 
+	epv->get_content_types = impl_get_content_types;
+
 	return epv;
 }
 
@@ -100,4 +119,33 @@ bonobo_persist_get_type (void)
 	return type;
 }
 
+/**
+ * bonobo_persist_generate_content_types:
+ * @num: the number of content types specified
+ * @...: the content types (as strings)
+ *
+ * Returns: a ContentTypeList containing the given ContentTypes
+ **/
+Bonobo_Persist_ContentTypeList *
+bonobo_persist_generate_content_types (int num, ...)
+{
+	Bonobo_Persist_ContentTypeList *types;
+	va_list ap;
+	char *type;
+	int i;
 
+	types = Bonobo_Persist_ContentTypeList__alloc ();
+	CORBA_sequence_set_release (types, TRUE);
+	types->_length = types->_maximum = num;
+	types->_buffer = CORBA_sequence_Bonobo_Persist_ContentType_allocbuf (num);
+
+	va_start (ap, num);
+	for (i = 0; i < num; i++) {
+		type = va_arg (ap, char *);
+		types->_buffer[i] = CORBA_string_alloc (strlen (type) + 1);
+		strcpy (types->_buffer[i], type);
+	}
+	va_end (ap);
+
+	return types;
+}
