@@ -125,12 +125,6 @@ typedef struct _MenuItemInternal {
 	 * not).
 	 */
 	gboolean sensitive;
-
-	/*
-	 * If this is a toggle item or a radio item, whether this item
-	 * is selected or not.
-	 */
-	gboolean active;
 } MenuItemInternal;
 
 /*
