@@ -1158,6 +1158,8 @@ toolbar_toplevel_item_create_widgets (BonoboUIHandler *uih,
 		break;
 
 	case BONOBO_UI_HANDLER_TOOLBAR_ITEM:
+	case BONOBO_UI_HANDLER_TOOLBAR_TOGGLEITEM:
+
 		pixmap = NULL;
 		if (internal->item->pixmap_data != NULL && internal->item->pixmap_type != BONOBO_UI_HANDLER_PIXMAP_NONE)
 			pixmap = bonobo_ui_handler_toplevel_create_pixmap (
@@ -1181,25 +1183,6 @@ toolbar_toplevel_item_create_widgets (BonoboUIHandler *uih,
 
 		break;
 
-	case BONOBO_UI_HANDLER_TOOLBAR_TOGGLEITEM:
-
-		if (internal->item->pos >= 0)
-			toolbar_item = gtk_toolbar_insert_element (GTK_TOOLBAR (toolbar),
-								   toolbar_type_to_gtk_type (internal->item->type),
-								   NULL, internal->item->label, internal->item->hint,
-								   NULL, NULL,
-								   GTK_SIGNAL_FUNC (toolbar_toplevel_item_activated),
-								   internal, internal->item->pos);
-		else
-			toolbar_item = gtk_toolbar_append_element (GTK_TOOLBAR (toolbar),
-								   toolbar_type_to_gtk_type (internal->item->type),
-								   NULL, internal->item->label, internal->item->hint,
-								   NULL, NULL,
-								   GTK_SIGNAL_FUNC (toolbar_toplevel_item_activated),
-								   internal);
-
-		break;
-
 	case BONOBO_UI_HANDLER_TOOLBAR_RADIOITEM:
 		g_warning ("Toolbar radio items/groups not implemented");
 		return;
@@ -1702,14 +1685,16 @@ bonobo_ui_handler_toolbar_new_radiogroup (BonoboUIHandler *uih, const char *path
 void
 bonobo_ui_handler_toolbar_new_radioitem (BonoboUIHandler *uih, const char *path,
 					const char *label, const char *hint, int pos,
+					BonoboUIHandlerPixmapType pixmap_type,
+					gpointer pixmap_data,
 					guint accelerator_key, GdkModifierType ac_mods,
 					BonoboUIHandlerCallbackFunc callback,
 					gpointer callback_data)
 {
 	bonobo_ui_handler_toolbar_new (uih, path, BONOBO_UI_HANDLER_TOOLBAR_RADIOITEM,
 				      label, hint, pos, CORBA_OBJECT_NIL,
-				      BONOBO_UI_HANDLER_PIXMAP_NONE,
-				      NULL, accelerator_key, ac_mods, callback, callback_data);
+				      pixmap_type, pixmap_data,
+				      accelerator_key, ac_mods, callback, callback_data);
 }
 
 /**
@@ -1718,14 +1703,16 @@ bonobo_ui_handler_toolbar_new_radioitem (BonoboUIHandler *uih, const char *path,
 void
 bonobo_ui_handler_toolbar_new_toggleitem (BonoboUIHandler *uih, const char *path,
 					 const char *label, const char *hint, int pos,
+					 BonoboUIHandlerPixmapType pixmap_type,
+					 gpointer pixmap_data,
 					 guint accelerator_key, GdkModifierType ac_mods,
 					 BonoboUIHandlerCallbackFunc callback,
 					 gpointer callback_data)
 {
 	bonobo_ui_handler_toolbar_new (uih, path, BONOBO_UI_HANDLER_TOOLBAR_TOGGLEITEM,
 				      label, hint, pos, CORBA_OBJECT_NIL,
-				      BONOBO_UI_HANDLER_PIXMAP_NONE,
-				      NULL, accelerator_key, ac_mods, callback,
+				      pixmap_type, pixmap_data,
+				      accelerator_key, ac_mods, callback,
 				      callback_data);
 }
 
@@ -2511,8 +2498,11 @@ toolbar_toplevel_item_set_pixmap_internal (BonoboUIHandler *uih, ToolbarItemInte
 					   BonoboUIHandlerPixmapType type, gpointer data)
 {
 	GtkToolbar *toolbar;
+	GtkWidget  *item;
 	GList      *l;
 	int         i;
+	char       *name;
+	int         len;
 
 	/*
 	 * Update the widgets.
@@ -2520,21 +2510,32 @@ toolbar_toplevel_item_set_pixmap_internal (BonoboUIHandler *uih, ToolbarItemInte
 	if (! toolbar_toplevel_item_is_head (uih, internal))
 		return;
 
-	toolbar = GTK_TOOLBAR (toolbar_toplevel_item_get_widget (uih, internal->item->path));
+	len = strchr (internal->item->path+1, '/') - internal->item->path;
+	name = g_strndup (internal->item->path+1, len - 1);
+
+	toolbar = GTK_TOOLBAR (toolbar_toplevel_get_widget (uih, name));
+	g_free (name);
 
 	i = 0;
-	for (l = toolbar->children; l; l = l->next) {
-		GtkToolbarChild *kid = l->data;
+	item = toolbar_toplevel_item_get_widget (uih, internal->item->path);
 
-		if (kid->label && !strcmp (GTK_LABEL (kid->label)->label, internal->item->label))
+	/* Loop through toolbar->children to the correct position */
+	for (l = toolbar->children; l; l = l->next) {
+		GtkToolbarChild *child;
+
+		child = l->data;
+		if (child->widget == item)
 			break;
 		i++;
 	}
+
 	if (l) {
 		GtkToolbarChild *kid = l->data;
 
 		/* Ugly remove code */
 		gtk_widget_destroy (kid->widget);
+		g_hash_table_remove (uih->top->path_to_toolbar_item_widget, internal->item->path);
+
 		toolbar->children = g_list_remove (toolbar->children, kid);
 
 		/*
@@ -2549,7 +2550,7 @@ toolbar_toplevel_item_set_pixmap_internal (BonoboUIHandler *uih, ToolbarItemInte
 		internal->item->pos = i;
 		toolbar_toplevel_item_create_widgets (uih, internal);
 	} else
-		g_warning ("Can't find toolbar to update pixmap");
+		g_warning ("Can't find toolbar item to update pixmap");
 }
 
 static void
