@@ -131,7 +131,7 @@ hydrate_object_from_file_cb (GtkWidget *ok_btn, Bonobo_PersistStream persist)
 		return;
 	}
 
-	Bonobo_PersistStream_load (persist, stream_obj, &ev);
+	Bonobo_PersistStream_load (persist, stream_obj, "", &ev);
         if (ev._major != CORBA_NO_EXCEPTION)
 		g_print ("The bonobo object failed to load the file %s\n",
 			 filename);
@@ -211,7 +211,7 @@ add_object_to_container (ODServerInfo *server_info)
 	view_frame = bonobo_client_site_new_view (client_site, CORBA_OBJECT_NIL);
 	view_widget = bonobo_view_frame_get_wrapper (view_frame);
 
-	frame = gtk_frame_new (view_widget);
+	frame = gtk_frame_new (od_server_info_get_name (server_info));
 	gtk_widget_show (frame);
 	gtk_box_pack_start (GTK_BOX (app->box), frame, TRUE, TRUE, 0);
 
