@@ -145,12 +145,19 @@ stream_read (Bonobo_Stream stream, embeddable_data_t *embeddable_data)
 /*
  * This function implements the Bonobo::PersistStream:load method.
  */
-static int
-pstream_load (BonoboPersistStream *ps, Bonobo_Stream stream,
-	      void *data)
+static void
+pstream_load (BonoboPersistStream *ps, const Bonobo_Stream stream,
+	      Bonobo_Persist_ContentType type, void *data,
+	      CORBA_Environment *ev)
 {
 	embeddable_data_t *embeddable_data = data;
 
+	if (*type && g_strcasecmp (type, "audio/ulaw") != 0) {	    
+		CORBA_exception_set (ev, CORBA_USER_EXCEPTION,
+				     ex_Bonobo_Persist_WrongDataType, NULL);
+		return;
+	}
+
 	/*
 	 * 1. Free the old sound data.
 	 */
@@ -159,29 +166,36 @@ pstream_load (BonoboPersistStream *ps, Bonobo_Stream stream,
 	/*
 	 * 2. Read the new sound data.
 	 */
-	if (stream_read (stream, embeddable_data) < 0)
-		return -1; /* This will raise an exception. */
+	if (stream_read (stream, embeddable_data) < 0) {
+		CORBA_exception_set (ev, CORBA_USER_EXCEPTION,
+				     ex_Bonobo_Persist_FileNotFound, NULL);
+		return;
+	}
 
 	/*
 	 * 3. Update the displays.
 	 */
 	bonobo_embeddable_foreach_view (embeddable_data->embeddable,
 				       update_view_foreach, embeddable_data);
-
-	return 0;
 } /* pstream_load */
 
 /*
  * This function implements the Bonobo::PersistStream:save method.
  */
-static int
-pstream_save (BonoboPersistStream *ps, Bonobo_Stream stream,
-	      void *data)
+static void
+pstream_save (BonoboPersistStream *ps, const Bonobo_Stream stream,
+	      Bonobo_Persist_ContentType type, void *data,
+	      CORBA_Environment *ev)
 {
 	embeddable_data_t  *embeddable_data = data;
 	Bonobo_Stream_iobuf *buffer;
 	size_t              pos;
-	CORBA_Environment   ev;
+
+	if (*type && g_strcasecmp (type, "audio/ulaw") != 0) {	    
+		CORBA_exception_set (ev, CORBA_USER_EXCEPTION,
+				     ex_Bonobo_Persist_WrongDataType, NULL);
+		return;
+	}
 
 	/*
 	 * Write the sound data into the stream.
@@ -197,18 +211,16 @@ pstream_save (BonoboPersistStream *ps, Bonobo_Stream stream,
 	buffer->_length = embeddable_data->sound_len;
 
 	pos = 0;
-	CORBA_exception_init (&ev);
 	
 	while (pos < embeddable_data->sound_len) {
 		CORBA_long bytes_read;
 
-		bytes_read = Bonobo_Stream_write (stream, buffer, &ev);
+		bytes_read = Bonobo_Stream_write (stream, buffer, ev);
 
-		if (ev._major != CORBA_NO_EXCEPTION) {
+		if (ev->_major != CORBA_NO_EXCEPTION) {
 			CORBA_free (buffer);
 			CORBA_free (data);
-			CORBA_exception_free (&ev);
-			return -1;
+			return;
 		}
 
 		pos += bytes_read;
@@ -216,11 +228,24 @@ pstream_save (BonoboPersistStream *ps, Bonobo_Stream stream,
 
 	CORBA_free (buffer);
 	CORBA_free (data);
-	CORBA_exception_free (&ev);
-	
-	return 0;
 } /* pstream_save */
 
+static CORBA_long
+pstream_get_max_size (BonoboPersistStream *ps, void *data,
+		      CORBA_Environment *ev)
+{
+	embeddable_data_t *embeddable_data = data;
+
+	return embeddable_data->sound_len;
+}
+
+static Bonobo_Persist_ContentTypeList *
+pstream_get_content_types (BonoboPersistStream *ps, void *closure,
+			   CORBA_Environment *ev)
+{
+	return bonobo_persist_generate_content_types (1, "audio/ulaw");
+}
+
 /*
  * Bonobo::ProgressiveDataSink
  *
@@ -370,9 +395,10 @@ embeddable_factory (BonoboEmbeddableFactory *this,  void *data)
 	/*
 	 * Register the Bonobo::PersistStream interface.
 	 */
-	stream = bonobo_persist_stream_new (pstream_load,
-					   pstream_save,
-					   embeddable_data);
+	stream = bonobo_persist_stream_new (pstream_load, pstream_save,
+					    pstream_get_max_size,
+					    pstream_get_content_types,
+					    embeddable_data);
 	if (stream == NULL) {
 		bonobo_object_unref (BONOBO_OBJECT (embeddable));
 		g_free (embeddable_data);
