@@ -503,20 +503,20 @@ view_activate_cb (BonoboView *view, gboolean activate, gpointer data)
  * save methods which allow data to be loaded into and out of the
  * BonoboObject.
  */
-static int
-stream_read (Bonobo_Stream stream, bonobo_object_data_t *bonobo_object_data)
+static void
+stream_read (Bonobo_Stream stream, bonobo_object_data_t *bonobo_object_data,
+	     CORBA_Environment *ev)
 {
 	Bonobo_Stream_iobuf *buffer;
 	CORBA_long bytes_read;
-	CORBA_Environment ev;
-
-	CORBA_exception_init (&ev);
 
 	do {
 
 #define READ_CHUNK_SIZE 65536
 		bytes_read = Bonobo_Stream_read (stream, READ_CHUNK_SIZE,
-						&buffer, &ev);
+						&buffer, ev);
+		if (ev->_major != CORBA_NO_EXCEPTION)
+			return;
 
 		bonobo_object_data->text = g_realloc (bonobo_object_data->text,
 						      bonobo_object_data->text_len
@@ -530,24 +530,24 @@ stream_read (Bonobo_Stream stream, bonobo_object_data_t *bonobo_object_data)
 
 		CORBA_free (buffer);
 	} while (bytes_read > 0);
-
-	CORBA_exception_free (&ev);
-
-	if (bytes_read < 0)
-		return -1;
-
-	return 0;
 } /* stream_read */
 
 /*
  * This function implements the Bonobo::PersistStream:load method.
  */
-static int
-pstream_load (BonoboPersistStream *ps, Bonobo_Stream stream,
-	      void *data)
+static void
+pstream_load (BonoboPersistStream *ps, const Bonobo_Stream stream,
+	      Bonobo_Persist_ContentType type, void *data,
+	      CORBA_Environment *ev)
 {
 	bonobo_object_data_t *bonobo_object_data = data;
 
+	if (*type && g_strcasecmp (type, "text/plain") != 0) {	    
+		CORBA_exception_set (ev, CORBA_USER_EXCEPTION,
+				     ex_Bonobo_Persist_WrongDataType, NULL);
+		return;
+	}
+
 	/*
 	 * 1. Free the old text data and blank the views.
 	 */
@@ -557,31 +557,35 @@ pstream_load (BonoboPersistStream *ps, Bonobo_Stream stream,
 	/*
 	 * 2. Read the new text data.
 	 */
-	if (stream_read (stream, bonobo_object_data) < 0)
-		return -1; /* This will raise an exception. */
+	stream_read (stream, bonobo_object_data, ev);
+	if (ev->_major != CORBA_NO_EXCEPTION)
+		return;
 
 	/*
 	 * 3. Update the displays.
 	 */
 	update_all_views (bonobo_object_data);
 
-	return 0;
 } /* pstream_load */
 
 /*
  * This function implements the Bonobo::PersistStream:save method.
  */
-static int
-pstream_save (BonoboPersistStream *ps, Bonobo_Stream stream,
-	      void *data)
+static void
+pstream_save (BonoboPersistStream *ps, const Bonobo_Stream stream,
+	      Bonobo_Persist_ContentType type, void *data,
+	      CORBA_Environment *ev)
 {
 	bonobo_object_data_t *bonobo_object_data = data;
 	Bonobo_Stream_iobuf *buffer;
 	size_t pos;
-	CORBA_Environment ev;
 
-	CORBA_exception_init (&ev);
-	
+	if (*type && g_strcasecmp (type, "text/plain") != 0) {	    
+		CORBA_exception_set (ev, CORBA_USER_EXCEPTION,
+				     ex_Bonobo_Persist_WrongDataType, NULL);
+		return;
+	}
+
 	/*
 	 * Write the text data into the stream.
 	 *
@@ -599,13 +603,12 @@ pstream_save (BonoboPersistStream *ps, Bonobo_Stream stream,
 	while (pos < bonobo_object_data->text_len) {
 		CORBA_long bytes_read;
 
-		bytes_read = Bonobo_Stream_write (stream, buffer, &ev);
+		bytes_read = Bonobo_Stream_write (stream, buffer, ev);
 
-		if (ev._major != CORBA_NO_EXCEPTION) {
+		if (ev->_major != CORBA_NO_EXCEPTION) {
 			CORBA_free (buffer);
 			CORBA_free (data);
-			CORBA_exception_free (&ev);
-			return -1;
+			return;
 		}
 
 		pos += bytes_read;
@@ -613,11 +616,24 @@ pstream_save (BonoboPersistStream *ps, Bonobo_Stream stream,
 
 	CORBA_free (buffer);
 	CORBA_free (data);
-	CORBA_exception_free (&ev);
-	
-	return 0;
 } /* pstream_save */
 
+static CORBA_long
+pstream_get_max_size (BonoboPersistStream *ps, void *data,
+		      CORBA_Environment *ev)
+{
+	bonobo_object_data_t *bonobo_object_data = data;
+
+	return bonobo_object_data->text_len;
+}
+
+static Bonobo_Persist_ContentTypeList *
+pstream_get_content_types (BonoboPersistStream *ps, void *closure,
+			   CORBA_Environment *ev)
+{
+	return bonobo_persist_generate_content_types (1, "text/plain");
+}
+
 /*
  * Bonobo::ProgressiveDataSink
  *
@@ -838,9 +854,10 @@ embeddable_factory (BonoboEmbeddableFactory *this,
 	/*
 	 * Register the Bonobo::PersistStream interface.
 	 */
-	stream = bonobo_persist_stream_new (pstream_load,
-					   pstream_save,
-					   bonobo_object_data);
+	stream = bonobo_persist_stream_new (pstream_load, pstream_save,
+					    pstream_get_max_size,
+					    pstream_get_content_types,
+					    bonobo_object_data);
 	if (stream == NULL) {
 		gtk_object_unref (GTK_OBJECT (bonobo_object));
 		g_free (bonobo_object_data);
