@@ -141,7 +141,7 @@ buffer_save_ps (Buffer *buffer, gchar *filename)
 
 	Bonobo_PersistStream_save (persist,
 	     (Bonobo_Stream) bonobo_object_corba_objref (BONOBO_OBJECT (stream)),
-				  &ev);
+				  "", &ev);
 
 	if (ev._major != CORBA_NO_EXCEPTION) {
 		gnome_warning_dialog (_("An exception occured while trying "
@@ -190,7 +190,7 @@ buffer_load_ps (Buffer *buffer, gchar *filename)
 
 	Bonobo_PersistStream_load (persist,
 	   (Bonobo_Stream) bonobo_object_corba_objref (BONOBO_OBJECT (stream)),
-				  &ev);
+				  "", &ev);
 
 	if (ev._major != CORBA_NO_EXCEPTION) {
 		gnome_warning_dialog (_("An exception occured while trying "
