@@ -1,4 +1,4 @@
-/* $Id */
+/* $Id: bonobo-hello.c,v 1.4 2000/05/23 16:43:08 cactus Exp $ */
 /*
   Bonobo-Hello Copyright (C) 2000 RDI Gerg <cactus@cactus.rulez.org>
   
@@ -32,50 +32,50 @@ static void
 init_bonobo_hello_factory (void)
 {
 #if USING_OAF
-	factory = bonobo_embeddable_factory_new (
-		"OAFIID:" PACKAGE "-factory:" VERSION,
-		hello_object_factory, NULL);
+	factory =
+	    bonobo_embeddable_factory_new ("OAFIID:bonobo-hello-factory:cactus",
+					   hello_object_factory,
+					   NULL);
 #else
-	factory = bonobo_embeddable_factory_new (
-		"bonobo-object-factory:hello",
-		hello_object_factory, NULL);
+	factory =
+	    bonobo_embeddable_factory_new ("bonobo-object-factory:hello",
+					   hello_object_factory, NULL);
 #endif
 }
 
 static void
 init_server_factory (int argc, char **argv)
 {
-	CORBA_Environment ev;    
+	CORBA_Environment ev;
 	CORBA_exception_init (&ev);
 
 #if USING_OAF
 	gnome_init_with_popt_table (PACKAGE, VERSION,
-				    argc, argv,
-				    oaf_popt_options, 0, NULL); 
+				    argc, argv, oaf_popt_options, 0, NULL);
 	oaf_init (argc, argv);
 #else
-	gnome_CORBA_init_with_popt_table (
-		PACKAGE, VERSION,             /* Name of the component */
-		&argc, argv,                  /* Command-line arguments */
-		NULL, 0, NULL,                /* popt table to parse arguments */
-		GNORBA_INIT_SERVER_FUNC, &ev  /* GNORBA options */
-		);
+	gnome_CORBA_init_with_popt_table (PACKAGE, VERSION,	/* Name of the component */
+					  &argc, argv,	/* Command-line arguments */
+					  NULL, 0, NULL,	/* popt table to parse arguments */
+					  GNORBA_INIT_SERVER_FUNC, &ev	/* GNORBA options */
+	    );
 #endif
 
 	if (!bonobo_init (CORBA_OBJECT_NIL,
 			  CORBA_OBJECT_NIL,
 			  CORBA_OBJECT_NIL))
-		g_error (_("I could not initialize Bonobo"));
+		    g_error (_("I could not initialize Bonobo"));
 
 	CORBA_exception_free (&ev);
 }
 
-int main (int argc, char **argv)
+int
+main (int argc, char **argv)
 {
 	init_server_factory (argc, argv);
 	init_bonobo_hello_factory ();
 
 	bonobo_main ();
-	
+
 	return 0;
 }
