@@ -1,4 +1,4 @@
-/* $Id */
+/* $Id: hello-object-io.h,v 1.4 2000/05/26 14:10:45 danw Exp $ */
 /*
   Bonobo-Hello Copyright (C) 2000 RDI Gerg <cactus@cactus.rulez.org>
   
@@ -22,11 +22,19 @@
 
 #include "hello-object.h"
 
-int hello_object_pstream_load (BonoboPersistStream *ps,
-			       Bonobo_Stream stream,
-			       void *data);
-int hello_object_pstream_save (BonoboPersistStream *ps,
-			       Bonobo_Stream stream,
-			       void *data);
+void hello_object_pstream_load (BonoboPersistStream * ps,
+				const Bonobo_Stream stream,
+				Bonobo_Persist_ContentType type,
+				void *data, CORBA_Environment *ev);
+void hello_object_pstream_save (BonoboPersistStream * ps,
+				const Bonobo_Stream stream,
+				Bonobo_Persist_ContentType type,
+				void *data, CORBA_Environment *ev);
+CORBA_long hello_object_pstream_get_max_size (BonoboPersistStream *ps,
+					      void *data,
+					      CORBA_Environment *ev);
+Bonobo_Persist_ContentTypeList *hello_object_pstream_get_types (BonoboPersistStream *ps,
+								void *closure,
+								CORBA_Environment *ev);
 
 #endif
