@@ -1,4 +1,4 @@
-/* $Id */
+/* $Id: hello-object.h,v 1.3 2000/05/23 16:43:08 cactus Exp $ */
 /*
   Bonobo-Hello Copyright (C) 2000 RDI Gerg <cactus@cactus.rulez.org>
   
@@ -25,6 +25,7 @@
 
 BonoboEmbeddableFactory *factory;
 
-BonoboObject* hello_object_factory (BonoboEmbeddableFactory *this, void *data);
+BonoboObject *hello_object_factory (BonoboEmbeddableFactory * this,
+				    void *data);
 
 #endif
